Class: Stupidedi::Schema::Generation::Models::ElementUse

Inherits:
Struct
  • Object
show all
Defined in:
lib/stupidedi/schema/generation/models.rb

Overview

An element referenced from a specific position within a segment. #max_reps is the element's repetition count: an integer for a bounded repeat, or nil for unbounded (">1"). A non-repeating element use is 1.

Instance Attribute Summary collapse

Instance Attribute Details

#elementObject

Returns the value of attribute element

Returns:

  • (Object)

    the current value of element



42
43
44
# File 'lib/stupidedi/schema/generation/models.rb', line 42

def element
  @element
end

#max_repsObject

Returns the value of attribute max_reps

Returns:

  • (Object)

    the current value of max_reps



42
43
44
# File 'lib/stupidedi/schema/generation/models.rb', line 42

def max_reps
  @max_reps
end

#positionObject

Returns the value of attribute position

Returns:

  • (Object)

    the current value of position



42
43
44
# File 'lib/stupidedi/schema/generation/models.rb', line 42

def position
  @position
end

#requirementObject

Returns the value of attribute requirement

Returns:

  • (Object)

    the current value of requirement



42
43
44
# File 'lib/stupidedi/schema/generation/models.rb', line 42

def requirement
  @requirement
end