Class: Stupidedi::Schema::Generation::Models::SegmentUse

Inherits:
Struct
  • Object
show all
Defined in:
lib/stupidedi/schema/generation/models.rb

Overview

A segment referenced from a specific position within a table or loop. #x12_sequence is the (string) sequence number from the standard, which takes precedence over #position when present.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#max_repsObject

Returns the value of attribute max_reps

Returns:

  • (Object)

    the current value of max_reps



77
78
79
# File 'lib/stupidedi/schema/generation/models.rb', line 77

def max_reps
  @max_reps
end

#positionObject

Returns the value of attribute position

Returns:

  • (Object)

    the current value of position



77
78
79
# File 'lib/stupidedi/schema/generation/models.rb', line 77

def position
  @position
end

#requirementObject

Returns the value of attribute requirement

Returns:

  • (Object)

    the current value of requirement



77
78
79
# File 'lib/stupidedi/schema/generation/models.rb', line 77

def requirement
  @requirement
end

#segmentObject

Returns the value of attribute segment

Returns:

  • (Object)

    the current value of segment



77
78
79
# File 'lib/stupidedi/schema/generation/models.rb', line 77

def segment
  @segment
end

#x12_sequenceObject

Returns the value of attribute x12_sequence

Returns:

  • (Object)

    the current value of x12_sequence



77
78
79
# File 'lib/stupidedi/schema/generation/models.rb', line 77

def x12_sequence
  @x12_sequence
end

Instance Method Details

#segment_use?Boolean

Returns:

  • (Boolean)


78
79
80
# File 'lib/stupidedi/schema/generation/models.rb', line 78

def segment_use?
  true
end